package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````C"%```````!``````````*#3````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````*2^````````I+X`````````
M`"````````$````&````\,T```````#PS6```````/#-8```````<`0`````
M``#8%```````````(````````@````8````(S@````````C.8```````",Y@
M``````#P`0```````/`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````&+@````````8N$```````!BX0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/#-````````\,U@``````#PS6``
M`````!`"````````$`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````&`````0`
M```4`````P```$=.50"P8*/XS(240M0;.FRC4`2,<C&4?1$```!&````!```
M``@````@'!``!4`$ABH"0`"0A@&HPBD`($D@!`NXHCA%N@0""D8```!'````
M2P```%````!1````5P```%D```!;````7P```&$`````````8P```&8```!G
M````:```````````````>_!*:V[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#GQ!
MCL6XC?$.U634?-EQ6!SB1\8!K$OCP+KCDGS"Y3\L^J%L8+,!BV]J"4/6A_F<
M@6:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`P4XI[)U;)QVLWCGC-BV^T,.I<+
M5J2;EJ?=HVM_J9R;X:<""@J*$%>CX/M)````````````````````````````
M`````````%0!```2`````````````````````````"D"```2````````````
M`````````````*@"```2`````````````````````````'T"```2````````
M`````````````````!$````@`````````````````````````*\"```2````
M`````````````````````#L#```2`````````````````````````-,````2
M`````````````````````````,0"```2`````````````````````````",#
M```2`````````````````````````!L#```2````````````````````````
M`*\````2`````````````````````````/0#```2````````````````````
M`````$\!```2`````````````````````````.<"```2````````````````
M`````````-("```2`````````````````````````)<"```2````````````
M`````````````#0#```2`````````````````````````%@#```2````````
M`````````````````+@!```2`````````````````````````'@!```2````
M`````````````````````-D"```2`````````````````````````.$````2
M``````````````````````````("```2`````````````````````````%8"
M```2`````````````````````````(X"```2````````````````````````
M`)\!```2`````````````````````````&8"```2````````````````````
M`````(4"```2`````````````````````````.\!```2````````````````
M`````````+T"```2`````````````````````````"0"```2````````````
M`````````````(T#```2`````````````````````````(8#```2````````
M`````````````````(8!```2`````````````````````````$L#```2````
M`````````````````````"T````@`````````````````````````/L"```2
M`````````````````````````'@````2``````````````````````````\!
M```2`````````````````````````$("```2````````````````````````
M`/L!```2`````````````````````````+X````2````````````````````
M`````*T!```2`````````````````````````&H````2````````````````
M`````````%D!```2``````````````````````````(#```2````````````
M`````````````.0!```2`````````````````````````!P!```2````````
M`````````````````+4"```2`````````````````````````#@!```2````
M`````````````````````!T"```2`````````````````````````'<#```2
M`````````````````````````%\#```2`````````````````````````,8!
M```2`````````````````````````'\#```2````````````````````````
M`,L"```2`````````````````````````#P````@````````````````````
M`````/,````2`````````````````````````$0#```2````````````````
M`````````)8!```2`````````````````````````!`#```2````````````
M`````````````'@"```2`````````````````````````#H"```2````````
M`````````````````.T"```2`````````````````````````(<````2````
M`````````````````````%`````@`````````````````````````.`"```2
M`````````````````````````&D#```2`````````````````````````-0!
M```2````L!M``````````````````/T#```2``T`P%=```````!O````````
M`,L#```2``X`!%E``````````````````"($```2``T`4$A```````!^"P``
M`````)H#```2``T`@!]````````,`@```````-$#```2``T``$)````````%
M`````````)`$```2``T`$$)```````"S`0```````+T$```2``T`,%A`````
M```Z`````````(H$```2``L``!M``````````````````-D$```2``T`T%-`
M``````#H`P```````+`#```0`!D`8-)@``````````````````D$```2``T`
MT$-````````D`````````#P$```1``\`$%E````````$`````````+P#```0
M`!D`R.)@`````````````````(@$```2``T`P$!````````J`````````)T$
M```2``T`,$=````````?`0```````*\$```2``T`H$9```````!4````````
M`"\$```0`!@`0-)@`````````````````)X````2````L!Y`````````````
M`````!8$```2``T``$1```````"_`````````)\#```1`!D`@-)@```````(
M`````````*D#```0`!@`8-)@`````````````````*`#```A`!D`@-)@````
M```(`````````'$$```1`!@`6-)@```````(`````````"T#```1`!D`B-)@
M```````(`````````,$#```2``T``%E````````"`````````&4!```2````
M\!U``````````````````&$$```2``T`D%A```````!E`````````#4$```2
M``T`C"%``````````````````#$$```@`!@`0-)@`````````````````"T!
M```1`!D`8-)@```````$`````````*$#```A`!D`@-)@```````(````````
M`.(#```2``T``$=````````D`````````$L$```2``T`0$%```````"Y````
M``````(!```1`!D`:-)@```````!`````````'L$```2``T`P$1```````#;
M`0````````!L:6)P97)L+G-O+C4N,3@`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8G!T:')E
M860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)C+G-O+C8`7U]R96=I<W1E
M<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A
M8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I
M9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F
M7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M
M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?
M961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U
M<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE
M86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?
M9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`>'-?
M:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C
M;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS
M7U!!4E]"3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`
M1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````@`#``(``@````(``@````(``@`"
M`````@````(``@`$``(``@```````@```````P`"````!0`"`````@`#``(`
M`@````8````'```````#``(````````````&```````"`````P`"``(````"
M``(```````(````"``(``P`&```````"``8````!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$````!``(``0`"``$``@`!`````0`!``$````"
M``$``0````$```````$``0`-`@``$````"````!U&FD)```#`.\$````````
M`0`%`%P"```0`````````)21E@8```<`^P0``!````!T&6D)```&``8%```0
M````<AEI"0``!0`2!0``$````!1I:0T```0`'@4``!````!U&FD)```"`.\$
M````````^,]@```````&````)0``````````````8-)@```````%````9```
M````````````:-)@```````%````:```````````````@-)@```````%````
M6@``````````````B-)@```````%````7@``````````````&-!@```````'
M`````0``````````````(-!@```````'`````@``````````````*-!@````
M```'`````P``````````````,-!@```````'````!```````````````.-!@
M```````'````!@``````````````0-!@```````'````!P``````````````
M2-!@```````'````"```````````````4-!@```````'````"0``````````
M````6-!@```````'````1@``````````````8-!@```````'````"@``````
M````````:-!@```````'````"P``````````````<-!@```````'````#```
M````````````>-!@```````'````#0``````````````@-!@```````'````
M#@``````````````B-!@```````'````#P``````````````D-!@```````'
M````$```````````````F-!@```````'````$0``````````````H-!@````
M```'````$@``````````````J-!@```````'````$P``````````````L-!@
M```````'````%```````````````N-!@```````'````%0``````````````
MP-!@```````'````%@``````````````R-!@```````'````%P``````````
M````T-!@```````'````&```````````````V-!@```````'````&0``````
M````````X-!@```````'````&@``````````````Z-!@```````'````&P``
M````````````\-!@```````'````'```````````````^-!@```````'````
M'0```````````````-%@```````'````'@``````````````"-%@```````'
M````'P``````````````$-%@```````'````(```````````````&-%@````
M```'````(0``````````````(-%@```````'````(@``````````````*-%@
M```````'````(P``````````````,-%@```````'````)```````````````
M.-%@```````'````)0``````````````0-%@```````'````)@``````````
M````2-%@```````'````)P``````````````4-%@```````'````*```````
M````````6-%@```````'````*0``````````````8-%@```````'````*@``
M````````````:-%@```````'````*P``````````````<-%@```````'````
M+```````````````>-%@```````'````8```````````````@-%@```````'
M````+0``````````````B-%@```````'````+@``````````````D-%@````
M```'````+P``````````````F-%@```````'````,```````````````H-%@
M```````'````,0``````````````J-%@```````'````,@``````````````
ML-%@```````'````,P``````````````N-%@```````'````-```````````
M````P-%@```````'````-0``````````````R-%@```````'````-@``````
M````````T-%@```````'````-P``````````````V-%@```````'````6```
M````````````X-%@```````'````.```````````````Z-%@```````'````
M.0``````````````\-%@```````'````.P``````````````^-%@```````'
M````/````````````````-)@```````'````/0``````````````"-)@````
M```'````/@``````````````$-)@```````'````/P``````````````&-)@
M```````'````0```````````````(-)@```````'````00``````````````
M*-)@```````'````0@``````````````,-)@```````'````1```````````
M````.-)@```````'````10``````````````2(/L"$B+!>VT(`!(A<!T!>A;
M`@``2(/$",,```````#_->*T(`#_)>2T(``/'T``_R7BM"``:`````#IX/__
M__\EVK0@`&@!````Z=#_____)=*T(`!H`@```.G`_____R7*M"``:`,```#I
ML/____\EPK0@`&@$````Z:#_____);JT(`!H!0```.F0_____R6RM"``:`8`
M``#I@/____\EJK0@`&@'````Z7#_____):*T(`!H"````.E@_____R6:M"``
M:`D```#I4/____\EDK0@`&@*````Z4#_____)8JT(`!H"P```.DP_____R6"
MM"``:`P```#I(/____\E>K0@`&@-````Z1#_____)7*T(`!H#@```.D`____
M_R5JM"``:`\```#I\/[___\E8K0@`&@0````Z>#^____)5JT(`!H$0```.G0
M_O___R52M"``:!(```#IP/[___\E2K0@`&@3````Z;#^____)4*T(`!H%```
M`.F@_O___R4ZM"``:!4```#ID/[___\E,K0@`&@6````Z8#^____)2JT(`!H
M%P```.EP_O___R4BM"``:!@```#I8/[___\E&K0@`&@9````Z5#^____)1*T
M(`!H&@```.E`_O___R4*M"``:!L```#I,/[___\E`K0@`&@<````Z2#^____
M)?JS(`!H'0```.D0_O___R7RLR``:!X```#I`/[___\EZK,@`&@?````Z?#]
M____)>*S(`!H(````.G@_?___R7:LR``:"$```#IT/W___\ETK,@`&@B````
MZ<#]____)<JS(`!H(P```.FP_?___R7"LR``:"0```#IH/W___\ENK,@`&@E
M````Z9#]____);*S(`!H)@```.F`_?___R6JLR``:"<```#I</W___\EHK,@
M`&@H````Z6#]____)9JS(`!H*0```.E0_?___R62LR``:"H```#I0/W___\E
MBK,@`&@K````Z3#]____)8*S(`!H+````.D@_?___R5ZLR``:"T```#I$/W_
M__\E<K,@`&@N````Z0#]____)6JS(`!H+P```.GP_/___R5BLR``:#````#I
MX/S___\E6K,@`&@Q````Z=#\____)5*S(`!H,@```.G`_/___R5*LR``:#,`
M``#IL/S___\E0K,@`&@T````Z:#\____)3JS(`!H-0```.F0_/___R4RLR``
M:#8```#I@/S___\E*K,@`&@W````Z7#\____)2*S(`!H.````.E@_/___R4:
MLR``:#D```#I4/S___\E$K,@`&@Z````Z4#\____)0JS(`!H.P```.DP_/__
M_R4"LR``:#P```#I(/S___\E^K(@`&@]````Z1#\____)?*R(`!H/@```.D`
M_/___R7JLB``:#\```#I\/O___\EXK(@`&A`````Z>#[____)=JR(`!H00``
M`.G0^____R72LB``:$(```#IP/O___\ERK(@`&A#````Z;#[____)<*R(`!H
M1````.F@^___4TB#[#")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(C50D".CI
M_?__NO`=0`"_L!Y``$B)UNBW.```@#VHLB```'4OZ-G\__](A<!(B07OPB``
M#X2F`0``2(G'Z`'\__^+/7NR(`#HQOW__\:`E0@```"+/6FR(`#HM/W__X"(
MK@0```*+/5>R(`#HHOW__X"(K@0```&+1"0<C7@%2&/_2(7_#X@8`0``\D@/
M*L?R#U@%TY<``&8/+@73EP``#X=$`0``2,'G`^BT_/__2(M,)!!(B050PB``
MQP5.PB``!````$B+$4C'0`CY6D``2,=`&/Q:0`!(B1!(BQ79L2``2(E0$(M4
M)!R#^@%^)XUR_DR-!/4(````,?8/'X``````2(M\,0A(B7PP($B#Q@A,.<9U
M[8U*!$B+/0/"(`"#P@-%,<"^\$!``$ACR4C'1,CX`````$B)P>A4_?__A<")
MPW0[2(L]U\$@`.AR^___2(UT)"PQP+^]64``Z'$8``!(A<!T*4B+/;7!(`#H
M\/K__^CK_/__2(/$,(G86\-(BSV<P2``Z-?]__^)P^NU2(L]A,$@`$B%_W0D
MZ((V``#KQ$B)^$B)^DC1Z(/B`4@)T/)(#RK`\@]8P.G0_O__2(UT)"R_<EE`
M`.@$&```2(7`2(D%0L$@`'2,2(G'Z[R_`0```.B9_?__Z-3\__\Q[4F)T5Y(
MB>)(@^3P4%1)Q\``64``2,?!D%A``$C'QX`?0`#H>_O___1F+@\?A```````
MN&?28`!52"U@TF``2(/X#DB)Y7<"7<.X`````$B%P'3T7;]@TF``_^`/'X``
M````N&#28`!52"U@TF``2,'X`TB)Y4B)PDC!ZC](`=!(T?AU`EW#N@````!(
MA=)T]%U(B<:_8-)@`/_B#Q^``````(`]6;`@``!U$55(B>7H?O___UW&!4:P
M(``!\\,/'T``2(,]J*L@``!T'K@`````2(7`=!15OP#.8`!(B>7_T%WI>___
M_P\?`.ES____#Q\`05=,C4<X,<E!5D%505154TB![!`"``!F#Q^$``````!)
MBQ0(2(G02(G62,'@"$C!YA@E``#_`(GV2`GP2(G62,'N"('F`/\``$@)\$B)
MUDC![AA`#[;V2`GP2(G62,'N($B)1$R(2(GP2,'F&$C!X`B)]B4``/\`2`GP
M2(G62,'J.$C![BB!Y@#_``!("?!("=!(B41,D$B#P0A(@_E`#X5[____2(U$
M)(A(C;0D\`$``$B-4&AF+@\?A```````2(M"V$@S`DB#P@A(,T*@2#-"D$B)
MP4@!P$C!Z1]("<&#X?](B4H02#GR==1(BQ=,BV\@3(M/"$R+5Q!,BV<83(GI
M2(G02`-,)(A(B=9(P>@;3(G-2,'F!4C![0)-B>!("?!,`T0DD$B)UHG`2/?6
M28G63(V<`9EY@EI,B<A,B=%(]]!,(<E,(=9,(>!)P>X"3(G32`G(2`-<))A)
M`<-,B<A(P>`>1(G92`G%B>U(B>A((=!("?!(B<Y-C80`F7F"6DB)R$C![AM(
MP>`%2`G&2(G02,'@'HGV20G&2(G(20'P18GV2/?01(G&32'S2"'H3`G83(V<
M`YEY@EI(B?!(B?-(P>,%2,'H&T@)V$B)RTC!X1Z)P$C!ZP))`<-("<M(`VPD
MH$B)\8G;1(G82/?122'83"'Q3`-T)*A,"<%,C80-F7F"6DB)P4B)Q4C!Y05(
MP>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)QDD!R(GM2/?61(G!2"'>22'K2`-<
M)+!,"=Y-C9PVF7F"6DB)SDF)SDG!Y@5(P>X;3`GV28G&2,'@'DG![@*)]DD)
MQDB)R$D!\T6)]DCWT$2)WDTA\$@AZ$P)P$R-A`.9>8):2(GP2(GS2,'C!4C!
MZ!M("=A(B<M(P>$>B<!(P>L"20'`2`G+2`-L)+A(B?&)VT2)P$CWT4DAVTPA
M\4P#="3`3`G93(V<#9EY@EI(B<%(B<5(P>4%2,'I&T@)Z4B)]4C!YAY(P>T"
MB<E("?5(B<9)`<N)[4CWUD2)V4@AWDDAZ$@#7"3(3`G&38V$-IEY@EI(B<Y)
MB<Y)P>8%2,'N&TP)]DF)QDC!X!Y)P>X"B?9)"<9(B<A)`?!%B?9(]]!$B<9-
M(?-((>A,"=A,C9P#F7F"6DB)\$B)\TC!XP5(P>@;2`G82(G+2,'A'HG`2,'K
M`DD!PT@)RT@#;"302(GQB=M$B=A(]]%)(=A,(?%,`W0DV$P)P4R-A`V9>8):
M2(G!2(G%2,'E!4C!Z1M(">E(B?5(P>8>2,'M`HG)2`GU2(G&20'(B>U(]]9$
MB<%((=Y)(>M(`UPDX$P)WDV-G#:9>8):2(G.28G.2<'F!4C![AM,"?9)B<9(
MP>`>2<'N`HGV20G&2(G(20'S18GV2/?01(G>32'P2"'H3`G`3(V$`YEY@EI(
MB?!(B?-(P>,%2,'H&T@)V$B)RTC!X1Z)P$C!ZP))`<!("<M(`VPDZ$B)\8G;
M1(G`2/?122';3"'Q3`-T)/!,"=E,C9P-F7F"6DB)P4B)Q4C!Y05(P>D;2`GI
M2(GU2,'F'DC![0*)R4@)]4B)QDD!RXGM2/?61(G92"'>22'H2`-<)/A,"<9-
MC80VF7F"6DB)SDF)SDG!Y@5(P>X;3`GV28G&2,'@'DG![@*)]DD)QDB)R$D!
M\$6)]DCWT$2)QDTA\T@AZ$P)V$F)\TB-G`.9>8):2(GP2<'C!4C!Z!M,"=A)
MB<M(P>$>B<!)P>L"2`'#20G+2`,L)$B)\46)VXG82/?132'83"'Q3`-T)`A,
M"<%,C80-F7F"6DB)P4B)Q4C!Y05(P>D;2`GI2(GU2,'F'DC![0*)R4@)]4B)
MQDD!R(GM2/?61(G!3"'>2"'K3`-<)!!("=Y)C9PVF7F"6DB)SDF)SDG!Y@5(
MP>X;3`GV28G&2,'@'DG![@*)]DD)QDB)R$@!\T6)]DCWT(G>32'P2"'H3`G`
M38V$`YEY@EI(B?!)B?-)P>,%2,'H&TP)V$F)RTC!X1Z)P$G!ZP))`<!)"<M(
M`VPD&$B)\46)VT2)P$CWT4PAVTPA\4P#="0@2`G92(G#2(VL#9EY@EI(B<%(
MP>,%2,'I&T@)V8G)2`'-2(GQ2,'F'DC!Z0*)ZT@)\4B)QD&)STCWUDTA^$PA
MWDP#7"0H3`G&28G83`-\)#!-C;0VF7F"6DB)WDG!X`5(P>X;3`G&B?9)`?9(
MB<9(P>`>2,'N`D6)\$@)QDR)P$@Q\4C!Z!LQS4R)P4C!X05)C:PKH>O9;D@)
MR$B)V4C!XQY(P>D"B<!("=E(`<5(B<A!B>M(,?!,B=N)]D$QQDR)V$C!XP5(
MP>@;3XVT-Z'KV6Y(`W0D.$@)V(G`20'&3(G`2<'@'DC!Z`)$B?-,"<!)B<!)
M,<B)R4@#3"1`1#'%28G82(VL+J'KV6Y(B=Y)P>`%2,'N&TP)QHGV2`'U3(G>
M2<'C'DC![@)!B>A,"=Y)B?-),<.)P$@#1"1(13'>38G#3HVT,:'KV6Y,B<%)
MP>,%2,'I&TP)V8G)20'.2(G92,'C'DC!Z0)%B?-("=E(B<M(,?.)]C'=3(G;
M2(VL**'KV6Y,B=A(P>@;2,'C!4@#="102`G8B<!(`<5,B<!)P>`>2,'H`HGK
M3`G`28G`23'(B<E(`TPD6$4QQDF)V$Z-M#:AZ]EN2(G>2<'@!4C![AM,"<:)
M]DD!]DR)WDG!XQY(P>X"18GP3`G>28GS23'#B<!(`T0D8$0QW4V)PTB-K"FA
MZ]EN3(G!2<'C!4C!Z1M,"=F)R4@!S4B)V4C!XQY(P>D"08GK2`G92(G+2#'S
MB?9!,=Y,B=M.C;0PH>O9;DR)V$C!XP5(P>@;2`G8B<!)`<9,B<!(P>@"2<'@
M'D@#="1H3`G`1(GS28G`23'(B<E(`TPD<$0QQ4F)V$B-K"ZAZ]EN2(G>2<'@
M!4C![AM,"<:)]D@!]4R)WDG!XQY(P>X"08GH3`G>28GS23'#B<!(`T0D>$4Q
MWDV)PTZ-M#&AZ]EN3(G!2<'C!4C!Z1M,"=F)R4D!SDB)V4C!XQY(P>D"18GS
M2`G92(G+2#'SB?8QW4R)VTB-K"BAZ]EN3(G82,'C!4C!Z!M("=B)P$@!Q4R)
MP$G!X!Y(P>@"B>M,"<!(`[0D@````$F)P$DQR(G)2`.,)(@```!%,<9)B=A.
MC;0VH>O9;DB)WDG!X`5(P>X;3`G&B?9)`?9,B=Y)P>,>2,'N`D6)\$P)WDF)
M\TDQPXG`2`.$))````!$,=U-B<-(C:PIH>O9;DR)P4G!XP5(P>D;3`G9B<E(
M`<U(B=E(P>,>2,'I`D&)ZT@)V4B)RT@Q\XGV2`.T))@```!!,=Y,B=M.C;0P
MH>O9;DR)V$C!XP5(P>@;2`G8B<!)`<9,B<!)P>`>2,'H`D2)\TP)P$F)P$DQ
MR(G)1#'%28G82(VL+J'KV6Y(B=Y(P>X;2<'@!4@#C"2@````3`G&B?9(`?5,
MB=Y)P>,>2,'N`D&)Z$P)WDF)\TDQPXG`2`.$)*@```!%,=Y-B<-.C;0QH>O9
M;DR)P4G!XP5(P>D;3`G9B<E)`<Y(B=E(P>,>2,'I`D6)\T@)V4B)RT@Q\XGV
M2`.T)+`````QW4R)VTB-K"BAZ]EN3(G82,'C!4C!Z!M("=B)P$@!Q4R)P$G!
MX!Y(P>@"B>M,"<!)B<!),<B)R44QQDF)V$Z-O#:AZ]EN2(G>2<'@!4C![AM,
M"<9-B=B)]DD!]TG!XQY)P>@"30G82`.,)+@```!%B?Y,B<9(,<:)P$@#A"3`
M````,?5,B?9,C9PIH>O9;DR)\4C!Y@5(P>D;2`GQ2(G>2,'C'DC![@*)R4@)
MWDD!RTB)\42)W4PQP46)P$$QSTB)Z4Z-O#BAZ]EN2(GH2,'A!4C!Z!M("<A,
MB?%)P>8>B<!(P>D"20''N-R\&X],"?%)B<9,`[0DR````$2)^TT!\$F)SDD)
M]DTA\TF)SDDA]HGV10GS3XTT&$F)V$F)VTG!XP5)P>@;30G818G`30'&28GH
M2,'E'DG!Z`)%B?-)">A(B<5(`ZPDT````$@![DR)Q4@)S4DA[TR)Q4@AS8G)
M00GO3(G=20'W3(G>2,'E!4C![AM(">Z)]DD!]TB)WDC!XQY(P>X"1(G]2`G>
M2(G#2`.<)-@```!(`=E(B?-,"<-)(=Y(B?-,(<-%B<!!"=Y(B>M)`<Y(B>E(
MP>,%2,'I&T@)V8G)20'.3(G92<'C'DC!Z0)$B?-,"=E)B<-,`YPDX````$T!
MV$F)RTD)\TTAWTF)RTDA\XGV10G?28G;30''28G82<'C!4G!Z!M-"=A%B<!-
M`<=)B>A(P>4>2<'H`D6)^TD)Z$B)Q4@#K"3H````2`'N3(G%2`G-22'N3(G%
M2"'-B<E!">Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C'DC![@)$
MB?5("=Y(B<-(`YPD\````$@!V4B)\TP)PTDAWTB)\TPAPT6)P$$)WTB)ZTD!
MSTB)Z4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"3X
M````30'828G+20GS32'>28G+22'SB?9%"=Y)B=M-`<9)B=A)P>,%2<'H&TT)
MV$6)P$T!QDF)Z$C!Y1Y)P>@"18GS20GH2(G%2`.L)``!``!(`>Y,B<5("<U)
M(>],B<5((<V)R4$)[TR)W4D!]TR)WDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>X"
M2,'C'D2)_4@)WDB)PT@#G"0(`0``2`'92(GS3`G#22'>2(GS3"'#18G`00G>
M2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!XQY(P>D"1(GS3`G928G#
M3`.<)!`!``!-`=A)B<M)"?--(=])B<M)(?.)]D4)WTF)VTT!QTF)V$G!XP5)
MP>@;30G818G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPD&`$``$@![DR)
MQ4@)S4DA[DR)Q4@AS8G)00GN3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)
MWDC!XQY(P>X"1(GU2`G>2(G#2`.<)"`!``!(`=E(B?-,"<-)(=](B?-,(<-%
MB<!!"=](B>M)`<](B>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,
M"=E)B<-,`YPD*`$``$T!V$F)RTD)\TTAWDF)RTDA\XGV10G>28G;30'&28G8
M2<'H&TG!XP5-"=A%B<!-`<9)B>A(P>4>2<'H`D6)\TD)Z$B)Q4@#K"0P`0``
M2`'N3(G%2`G-22'O3(G%2"'-B<E!">],B=U)`?=,B=Y(P>4%2,'N&T@)[HGV
M20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPD.`$``$@!V4B)\TP)PTDAWDB)
M\TPAPT6)P$$)WDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E(P>D"2<'C
M'D2)\TP)V4F)PTP#G"1``0``30'828G+20GS32'?28G+22'SB?9%"=])B=M-
M`<=)B=A)P>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"18G[20GH2(G%2`.L
M)$@!``!(`>Y,B<5("<U)(>Y,B<5((<V)R4$)[DR)W4D!]DR)WDC!Y05(P>X;
M2`GNB?9)`?9(B=Y(P>,>2,'N`D2)]4@)WDB)PT@#G"10`0``2`'92(GS3`G#
M22'?2(GS3"'#18G`00G?2(GK20'/2(GI2,'C!4C!Z1M("=F)R4D!STR)V4G!
MXQY(P>D"1(G[3`G928G#3`.<)%@!``!(`X0D8`$``$T!V$F)RTD)\TTAWDF)
MRTDA\XGV10G>28G;2`'P30'&28G82<'C!4G!Z!M-"=A%B<!-`<9)B>A(P>4>
M2<'H`D6)\TD)Z$R)QD@)SDDA]TR)QD@ASHG)00GW3(G>20''3(G82,'H&TC!
MY@5("?!(B=Y(P>,>B<!(P>X"20''N-;!8LI("=Y(B<-(`YPD:`$``$2)_4@!
MV4B)\TPQPT6)P$$QWDB)ZTD!SDB)Z4C!XP5(P>D;2`G9B<E)`<Y,B=E)P>,>
M2,'I`D2)\TP)V4F)PTP#G"1P`0``30'828G+23'SB?9%,=])B=M-`<=)B=A)
MP>,%2<'H&TT)V$6)P$T!QTF)Z$C!Y1Y)P>@"18G[20GH2(G%2`.L)'@!``!(
M`>Y,B<5(,<V)R4$Q[DR)W4D!]DR)WDC!Y05(P>X;2`GNB?9)`?9(B=Y(P>,>
M2,'N`D2)]4@)WDB)PT@#G"2``0``2`'92(GS3#'#18G`03'?2(GK20'/2(GI
M2,'C!4C!Z1M("=F)R4D!STR)V4G!XQY(P>D"1(G[3`G928G#3`.<)(@!``!-
M`=A)B<M),?.)]D4QWDF)VTT!QDF)V$G!XP5)P>@;30G818G`30'&28GH2,'E
M'DG!Z`)%B?-)">A(B<5(`ZPDD`$``$@![DR)Q4@QS8G)03'O3(G=20'W3(G>
M2,'E!4C![AM(">Z)]DD!]TB)WDC!XQY(P>X"1(G]2`G>2(G#2`.<))@!``!(
M`=E(B?-,,<-%B<!!,=Y(B>M)`<Y(B>E(P>,%2,'I&T@)V8G)20'.3(G92<'C
M'DC!Z0)$B?-,"=E)B<-,`YPDH`$``$T!V$F)RTDQ\XGV13'?28G;30''28G8
M2<'C!4G!Z!M-"=A%B<!-`<=)B>A)P>@"2,'E'D6)^TD)Z$B)Q4@#K"2H`0``
M2`'N3(G%2#'-B<E!,>Y,B=U)`?9,B=Y(P>4%2,'N&T@)[HGV20'V2(G>2,'C
M'DC![@)$B?5("=Y(B<-(`YPDL`$``$@!V4B)\TPQPT6)P$$QWTB)ZTD!STB)
MZ4C!XP5(P>D;2`G9B<E)`<],B=E)P>,>2,'I`D2)^TP)V4F)PTP#G"2X`0``
M30'828G+23'SB?9%,=Y)B=M-`<9)B=A)P>@;2<'C!4T)V$6)P$T!QDF)Z$C!
MY1Y)P>@"18GS20GH2(G%2`.L),`!``!(`>Y,B<5(,<V)R4$Q[TR)W4D!]TR)
MWDC!Y05(P>X;2`GNB?9)`?=(B=Y(P>,>2,'N`D2)_4@)WDB)PT@#G"3(`0``
M2`'92(GS3#'#18G`03'>2(GK20'.2(GI2,'C!4C!Z1M("=F)R4D!SDR)V4G!
MXQY(P>D"1(GS3`G928G#3`.<)-`!``!-`=A)B<M),?.)]D4QWTF)VTT!QTF)
MV$G!XP5)P>@;30G818G`30''28GH2,'E'DG!Z`)%B?M)">A(B<5(`ZPDV`$`
M`$@![DR)Q4@QS8G)03'N3(G=20'V3(G>2,'E!4C![AM(">Z)]DD!]DB)WDC!
MXQY(P>X"1(GU2`G>2(G#2`.<).`!``!(`=E(B?-,,<-%B<!!,=](B>M)`<](
MB>E(P>,%2,'I&T@)V8G)20'/3(G92<'C'DC!Z0)$B?M,"=E)B<-,`YPDZ`$`
M`$T!V$F)RTDQ\XGV13'>28G;30'&28G82<'C!4G!Z!M-"=A%B<!-`<9)B>A(
MP>4>2<'H`D6)\TD)Z$B)Q4@#K"3P`0``2`'N3(G%2#'-B<E!,>],B=U)`?=,
MB=Y(P>4%2,'N&T@)[HGV20'W2(G>2,'C'DC![@)$B?U("=Y(B<-(`YPD^`$`
M`$@!V4B)\TPQPT6)P$$QWDJ-'#%(B>E)B>Y)P>8%2,'I&TP)\0'+3(G92,'I
M`DG!XQY(`X0D``(``$P)V4F)ZTC!Y1Y)P>L"00'920GK2(G=3`'`28G(2,'E
M!4DQ\$0!X40![D4QQT4!VDZ-!#A(B=A(P>@;2`GH1`'``<)(B1=,B4\(3(E7
M$$B)3QA(B7<@2('$$`(``%M=05Q!74%>05_##Q^``````$%7059!54F)_4%4
M55-(@^P(2(7_=&A,BS7SF"``387V=%P/M@=)B?<\/71DA,!T8$F)_$F#Q`%!
M#[8$)#P]=`2$P'7O12GL28L>2(7;="]-8^1,B?4/'P!,B>),B>Y(B=_HBN'_
M_X7`=0="@#PC/70G2(/%"$B+70!(A=MUVDB#Q`@QP%M=05Q!74%>05_#D$4Q
MY.NR#Q\`3"GU2HU$(P%(P?T#08DO2(/$"%M=05Q!74%>05_#9BX/'X0`````
M`%-(B?M(@^P0#Q^$``````!(C70D##'`2(G?Z"'___](A<!T+DAC5"0,2(L%
M()@@`$B-!-!(BU`(2(722(D0=-!(@\`(2(M0"$B%TDB)$'7PZ[Y(@\006\,/
M'X0``````$%7,<!!5D%5051)B?Q54TB)\TB#[!B`/CT/E,!(`<-(B=_H:>'_
M_TB-="0,28G%3(GG,<#HI_[__TB%P$B)Q0^$^P```$B)Q^A#X?__1(GJ2#G0
M#X//````BVPD#$$/M@0D/#T/A(8!``"$P`^$?@$``$R)XNL-9@\?A```````
MA,ET#$B#P@$/M@J`^3UU\$0IXDB+!5:7(`!"C7PJ`DB-+.CHB.+__TB%P$B)
M10`/A$X!``"+5"0,2(L%,)<@`$F-3"0!2(L4T$$/M@0DA,"(`G4>ZR!F+@\?
MA```````2(/!`0^V0?](@\(!A,"(`G0$/#UUZL8"/3'`#Q]$```/M@P#B$P"
M`4B#P`&$R77P,<!(@\086UU!7$%=05Y!7\,/'X``````2(/#`0^V0_](@\4!
MA,"(1?]U[>O3#Q\`3(LUJ98@`$F#/@`/A*8```!,B?`Q[68N#Q^$``````!(
M@\`(@\4!2(,X`'7SC74"2&/V2,'F`XL%DZ8@`(7`="],B??H-^+__TB%P$B)
M!5V6(`!T;DQC_4B)P4K'1/D(`````(EL)`SIL/[__P\?`$B)]\<%4Z8@``$`
M``#H;N'__TB%P'0\3&/]3(GV2(G'2HT4_0````#H$^+__TB)P4B)!0F6(`#K
ML@\?@``````QTNF<_O__OA`````Q[>ET____N/_____I!?___P\?`$%50515
M2(G]4TB![)@```!(A?]T!8`_`'462('$F````%M=05Q!7<,/'X0``````.C[
MWO__2(7`28G$=-U,B>?HJ^'__TB%P$B)PP^$GP```(![$RX/A+4```!(@\,3
M2(GOZ!G?__](B=])B<7H#M___T&-?`4"2&/_Z*'@__])B=E)B<5(B<=)B>BY
M%%E``$C'PO____^^`0```#'`Z"WB__^_`0```$B)XDR)[NAMWO__@_C_3(GO
M=!"+1"08)0#P```]`$```'1MZ.#=__],B>_HN-W__TR)Y^@0X?__2(7`2(G#
M#X5E____#Q]``$R)Y^@HW___2(GOZ'#>__](@<28````6UU!7$%=PV:0#[9#
M%(3`#X0A____/"X/A3?___^`>Q4`#X0/____9I#I)O___P\?`.C#_O__#Q\`
MZXYF9F9F9BX/'X0``````%532(/L"(L]9)0@`.BOW___BSU9E"``2(N`P```
M`$B+:`CHF=___XL]0Y0@``^VF)T```#HA]___TB+0`B#XW\/MT`@P>`'"=AF
MB44"BST=E"``Z&C?__^+/1*4(`!(BX#`````2(M8".A2W___,=*^\UI``$B)
MQ^@SW___BSWMDR``2(E#*.@TW___BSW>DR``2(N`P````$B+6`CH'M___TB+
M@(@&``"+/<&3(`!(B4,PZ`C?__^+/;*3(`!(BX#`````2(M8".CRWO__,=)(
M@[C(`0```'09BSV0DR``Z-O>__](BX#(`0``2(N0J````(L]=Y,@`$B)4SCH
MOM[__TB+@,````"+/6&3(`!(BT`(2,=`0`````#HH-[__TB+@,````"+/4.3
M(`!(BT`(2,=`(`````#H@M[__XL]+),@`$B+@,````!(BU@(Z&S>__](BX"`
M`P``2(E#2$B#Q`A;7<-F+@\?A```````4TB)^XL]]I(@`.A!WO__2(V0X`$`
M`$B)WK\!````Z(W?__^%P'0),<!;PP\?1```BSW*DB``Z!7>__^+@/@!```E
M`/```#T`0```=!V+/:V2(`#H^-W__XN`^`$``"4`\```/0"@``!UO4B)W[X"
M````Z.G>__^%P`^4P`^VP%O#9F9F9F9F+@\?A```````052Z_P\``$F)]%5(
MB?V_&EE``%-(@>P0$```2(GF9$B+!"4H````2(F$)`@0```QP.A:V___A<!^
M;HU(_TACV8`\'`!T6DACV$B)VKXO````2(GGZ,?<__](A<!T2HL]#)(@`.A7
MW?__2(G92(GB2(GN2(G'Z';>__](BX0D"!```&1(,P0E*````'4V2('$$!``
M`%M=05S##Q^``````(7)=:4/'T``BSW"D2``Z`W=__],B>)(B>Y(B<?HO]O_
M_^NWZ'C;__\/'X0``````$B#[`B+/9:1(`#HX=S__[DI64``NK`;0`"^,UE`
M`$B)QTB#Q`CI]MS__V8/'T0``$B#[`B+/6:1(`#HL=S__TB)Q^BY____BSU3
MD2``Z)[<__]!N/-:0`!%,<FZT%-``$R)P;Y/64``2(G'2(/$".D,W?__9F9F
M+@\?A```````4TB!["`@``!D2(L$)2@```!(B80D&"```#'`Z$#:__]!N259
M0`!!B<"Y9%E``#'`N@$0``"^`0```$B)Y^CNW?__A<!X:DB-M"00$```N@`0
M``!(B>?HY=G__X7`2(G#>$Z->`%(8__H$]S__TB%P'0^2&/;2(VT)!`0``!(
MB<=(B=KHN-O__\8$&`!(BY0D&"```&1(,Q0E*````'452('$("```%O##Q^$
M```````QP.O8Z#?:__\/'X``````Z3O___]F9BX/'X0``````$%5051)B?R_
M<EE``%532(GS2('L.!```&1(BP0E*````$B)A"0H$```,<!(C70D'.@K]___
MOB\```!,B>=(B<7H^]G__TB%P'0W3(GFOWM90``QP.@G^/__3(G@2(NT)"@0
M``!D2#,T)2@````/A3L!``!(@<0X$```6UU!7$%=PTR)Y^B'V?__2(G?OHA9
M0`!!B<7H)]S__TB)PP\?0`!(A=MTI8`[`+AP64``2`]$V$B%[7032(G>2(GO
MZ&_:__^%P`^$H````$B)W^@_V?__B<%(F$B-5`/_@#HO=1"0Q@(`2(/J`8/I
M`8`Z+W3Q08U$#0$]_P\```^/2____TB-?"0@0;F*64``28G8N:E:0`"Z`!``
M`+X!````,<!,B20DZ#G<__^+/2./(`#H;MK__TB-="0@2(V0X`$``+\!````
MZ&C8__^%P'4=BSW^CB``Z$G:__^+@/@!```E`/```#T`@```=!2^B%E``#'_
MZ$O;__](B</I(____TB-?"0@O@$```#H)-O__X7`==E(C70D(+][64``Z.'V
M__](C7PD(.@WV?__Z:[^___H;=C__V9F9F8N#Q^$```````/M@](B?B$R708
M2(U7`6:0@/DO#[8*2`]$PDB#P@&$R77N\\-F9F8N#Q^$``````!(A?]32(G[
M="^`/P!T*N@-V/__2(U4`_](.=-R#.M'D$B#Z@%(.=IT!X`Z+W3RZRV`.B]U
M?P\?`+\"````Z'[9__](A<!T:;HN````9HD06\,/'X``````@#HO=`E(@^H!
M2#G3<O)(.=IU"NO##Q\`@#HO=0E(@^H!2#G3<O)(*=I(C4("2#T`$```=R-(
MB=Y(@\(!N0`0``"_H-)@`.A]V?__N*#28`!;PV8/'T0``#'`6\-;OXI90`#I
M,=C__Y!(@^Q(OXQ90`!D2(L$)2@```!(B40D.#'`2(L%(!8``$B)1"002(L%
M'!8``$B)1"082(L%&!8``$B)1"0@2(L%%!8``$B)1"0H#[<%$!8``&:)1"0P
M,<#H%/7__S'`OY590`#H"/7__S'`OYU90`#H_/3__S'`OZ990`#H\/3__S'`
MOZU90`#HY/3__S'`O[U90`#HV/3__S'`OW)90`#HS/3__S'`O\E90`#HP/3_
M_S'`O]-90`#HM/3__S'`O]U90`#HJ/3__S'`OWM90`#HG/3__S'`O^=90`#H
MD/3__S'`O_!90`#HA/3__TB-="0,,<"_^UE``.BS\___2(7`=`](B<:_TUE`
M`#'`Z+_T__](C70D##'`OPQ:0`#HCO/__TB%P'0/2(G&OQY:0``QP.B:]/__
M2(UT)`PQP+\I6D``Z&GS__](A<!T/$B)QK]R64``,<#H=?3__S'`OE5:0`"_
MK5E``.AD]/__2(M$)#AD2#,$)2@```!U6DB#Q$C##Q^``````$B-="0,,<"_
M.5I``.@7\___2(7`=!)(B<:_R5E``#'`Z"/T___KK)!(C70D(;]*6D``N0H`
M``#SIG682(UT)"N_R5E``#'`Z/SS___KA>B5U?__#Q]$``"+!:J+(`"#^/]T
M!<,/'T``2(/L&#'`O\E90`!(C70D#.BK\O__2(7`="8/MA`QP(32=`@QP(#Z
M,`^5P(D%;XL@`$B#Q!C#9BX/'X0``````#'`Z^=F9F8N#Q^$``````!(@^P(
MZ#?5__^)Q^C@U/__2(7`=`M(BP!(@\0(PP\?`#'`Z_1F9F8N#Q^$``````!!
M5T%628G^055!O6%:0`!!5%6]5UI``%-(@^QH2,=$)"!A6D``2,=$)"A76D``
M3(UD)#!(QT0D,&1:0`!(QT0D.%I:0`!(QT0D0%]:0`!(QT0D2'%:0`!(QT0D
M4`````#K)F8/'T0``$B)Q^C`U___2(7`=%-(A>UT/$F+!"1)B>U)@\0(2(G%
M2(UT)!PQP$R)[^BI\?__2(7`2(G#3(GV=`6`.`!UP4R)[S'`Z*_R__](A>UU
MQ$B#Q&A;74%<05U!7D%?PP\?`$R)]^@@U/__2(G?28G'Z!74__])C7P'`NBK
MU?__2(D<)$F)QTB)QT&YB%E``$V)\+FI6D``2,?"_____[X!````,<#H,-?_
M_TR)_DR)[S'`Z$/R___KDI!!5T%6055!5$F)_+]R64``55-(@>R8@0``9$B+
M!"4H````2(F$)(B!```QP$B-="0\2,=$)$"(6D``2,=$)$AP64``2,=$)%``
M````2,>$)(`````>6D``2,>$)(@````76D``2,>$))````"-6D``2,>$))@`
M```T6D``2,>$)*````"56D``2,>$)*@`````````2,=$)&!\6D``2,=$)&B9
M6D``2,=$)'``````Z&SP__](A<!T"8`X``^%1@0``#'`Z.?]__](A<!(B<,/
MA%($``!(B=_H\]+__TB-?``!Z(G4__^`.P!)B<5(B<5T,F8/'T0``$0/M@-(
MB>\QP+FB6D``2,?"_____[X!````2(/#`4B#Q0+H`=;__X`[`'742(VL)(@`
M``"_'EI``.L2#Q]$``!(@\4(2(M]^$B%_W0[2(UT)#PQP.C/[___2(7`2(G#
M=-^`.`!TVDB)Q^BJ]?__A<!TSDB)W^@NT___2(7`2(G#=5]F#Q]$``!(BUPD
M0$B%VP^$6@$``(`[`+T!````=27I2P$```\?`$ACQ4B+7,1`2(7;#X0W`0``
M@\4!@#L`#X0K`0``2(G?Z$OU__^%P'372(G?Z,_2__](A<!(B<-TQTB)W^CO
MT?__3(GIBS%(@\$$C9;__O[^]]8A\H'B@("`@'3HB=;![A#WPH"````/1-9(
MC7$"2`]$S@#22(/9`TPIZ42-M`@$!```36/V3(GWZ$+3__]!N8I90`!(B<=(
MB<5)B=BYIUI``$C'PO____^^`0```#'`3(EL)`A(QP0DL%I``.B^U/__OL`!
M``!(B>_HL=#__X/X_W1\BSV6AR``Z.'2__](C9#@`0``2(GNOP$```#H+=3_
M_X7`#X2-````28L,)$B+/9*'(`!)B>BZ:%M``+X!````,<#H-M3__S'`2(N4
M)(B!``!D2#,4)2@````/A9T(``!(@<28@0``6UU!7$%=05Y!7\,/'P`QV^GJ
M_O__D.C[S___1(L(08/Y$0^$<O___TF+#"1(BSTKAR``28GHNBA;0`"^`0``
M`#'`Z,_3__\QP.N7#Q\`BSWBAB``Z"W2__^+@/@!```E`/```#T`0```#X52
M____BSW!AB``Z`S2__^+F/P!``#HD=#__SG##X4T____BSVCAB``Z.[1__^+
M@/@!```E_P$``#W``0``#X43____3(GWZ.#1__](C70D/+]:6D``2(G#,<#H
M?.W__TB%P$B)QP^$Q0<``.CKT/__28L\)$B)QNC_]?__2(7`28G%#X2H!P``
M3(GOZ/O/__^#^`-^-DACT+^U6D``N04```!)C705_/.F=2"#^`0/A'H&``"#
MZ`1(F$&`?`7_+P^$:08``&8/'T0``#'`Z#GZ__^%P'46,?9,B>_H^]'__X7`
MB40D(`^%3P$``+Y56D``O\E90``QP.C^[?__Z`G/__](QT0D"/-:0`")!"1!
MN8I90`!)B>BYSEI``$C'PO____^^`0```$B)WS'`Z*G2__]%,>3K3`\?0`#H
M:\[__X,X$75008/$`>B]SO__2,=$)!#S6D``B00D0;F*64``1(ED)`A)B>BY
MW%I``$C'PO____^^`0```$B)WS'`Z%C2__^^P`$``$B)W^A+SO__@_C_=*9(
MB>_H_LW__TB)WK]R64``,<#H3^W__TB)W^CG^?__2(G8Z;O]__\/'X``````
M2(G'2(E$)"#HR_G__TB+1"0@2(G'Z'[/___IE?W__[]\6D``O0$```#K%0\?
M1```2&/%@\4!2(M\Q&!(A?]T*TB-="0\,<#HS.O__TB%P'3?@#@`=-I(B<?H
M.L___TB%P$B)PW3*Z6+[__]`MPV[@5I``.EB^___N@(```!(Q\;N____B<=!
MB<;H2M'__TB-M"2``0``N@8```!$B??H)<___X"\)(`!````=0Z`O"2!`0``
M0P^$+04``(M\)"`QTC'VZ!#1__^XB:O-[TC'A"0``0```2-%9TC'A"08`0``
M=E0R$$B)A"0(`0``N/[<NIA(QX0D*`$```````!(B80D$`$``+CPX=+#2,>$
M)#`!````````2(F$)"`!``!(C80D.`$``,>$)'@!````````2(E$)"B0BWPD
M($B-M"2``0``N@"```#H>L[__X7`28G'08G$#XZ9`0``2(NT)"@!``!)8\>-
M%,9(.=9(B[0D,`$``'8$2(/&`4C!Z!U(B90D*`$``$@!\$B)A"0P`0``2&.$
M)'@!``"%P`^$1@$``+I`````2(V\!#@!``!(C;0D@`$``"G"03G700].UTQC
MZD&)U$R)ZNA:SO__BX0D>`$``$0!X(/X0(F$)'@!```/A5#___]$B?A(C;PD
M``$``$0IX$&)Q$B-A"2``0``20'%Z!_3__\/'X``````08/\/P^.I0```$6)
MYDV)[P\?A```````28L/2(V\)``!``!!@^Y`28/'0$B)C"0X`0``28M/R$B)
MC"1``0``28M/T$B)C"1(`0``28M/V$B)C"10`0``28M/X$B)C"18`0``28M/
MZ$B)C"1@`0``28M/\$B)C"1H`0``28M/^$B)C"1P`0``Z(S2__]!@_X_?X9!
M@^Q`1(GBP>H&B=#!X@9(@\`!02G42,'@!DD!Q4B+?"0H26/4N4@```!,B>[H
M-,W__T2)I"1X`0``Z5?^__\/'X``````3(VL)(`!``#I&____XM\)"#H6LS_
M_TR+I"0H`0``3(NL)#`!``!,B>!(P>@#@^`_C4@!2&/0QH04.`$``("#^3@/
MCW8"``"Z-P```$ACR3'V*<)(C;P,.`$``$ACTNC=R___3(GH2(V\)``!``!$
MB*PD<P$``$C!Z!A$B*0D=P$``$R-O"30````B(0D<`$``$R)Z$C!Z!!-C7<H
MB(0D<0$``$R)Z$R-K"2Q````2,'H"(B$)'(!``!,B>!(P>@8B(0D=`$``$R)
MX$C!Z!"(A"1U`0``3(G@38G\2,'H"(B$)'8!``#H5='__TB+A"0``0``2(G"
MB(0DLP```$C!ZAA$#[;"B)0DL````$B)PDC!ZA"(E"2Q````2(G"2(N$)`@!
M``!(P>H(B)0DL@```$B)PHB$)+<```!(P>H8B)0DM````$B)PDC!ZA"(E"2U
M````2(G"2(N$)!`!``!(P>H(B)0DM@```$B)PHB$)+L```!(P>H8B)0DN```
M`$B)PDC!ZA"(E"2Y````2(G"2(N$)!@!``!(P>H(B)0DN@```$B)PHB$)+\`
M``!(P>H8B)0DO````$B)PDC!ZA"(E"2]````2(G"2(N$)"`!``!(P>H(B)0D
MO@```$B)PHB$),,```!(P>H8B)0DP````$B)PDC!ZA"(E"3!````2(G"2,'J
M"(B4),(```#I$`````\?@`````!%#[9%`$F#Q0%,B><QP+FB6D``2,?"____
M_[X!````28/$`NCPS/__33GT==/&A"3X`````$C'1"0(\UI``$R)/"1!N8I9
M0`!)B>BYOUI``$C'PO____^^`0```$B)WS'`Z++,___I9_K__TV+9"0(387D
M#X2/^?__3(GGZ$?)__](@_@##X9]^?__28UT!/R_NEI``+D%````\Z9-#T3L
MZ6/Y__](8\FZ/P```#'V2(V\##@!```IPDACTNAGR?__2(V\)``!``#H6L__
M_TB-E"0X`0``N0<````QP$B)U_-(J^EC_?__@+PD@@$``$$/A<7Z__^`O"2#
M`0``0P^%M_K__X"\)(0!``!(#X6I^O__@+PDA0$``$4/A9OZ__]$BW0D(+H"
M````2,?&QO___T2)]^B?R___2(VT)(`!``"Z*0```$2)]^AZR?__2(V$)(`!
M``!(QT0D"/-:0`!(B00DZ=K^___H:\C__TV++"3I3_C__V:0055!5%532(/L
M&(L]@'X@`.C+R?__2(UT)`S&@)D````!OZU90``QP.ASY?__2(7`=`F`.#$/
MA'4"```QP.BN\/__BSU(?B``Z)/)__^Y"P```+H!````ONU:0`!(B<?H',G_
M_TB%P`^$O````(,];(X@``%(BT`03(MH*`^.IP```+T(````,=OK,@\?1```
M28MT)!!(BP4\CB``2(L\*.C+R/__A<!U;X/#`8L%+HX@`$B#Q0B-4P$YPGUA
MBSW-?2``Z!C)__\QR8G:3(GN2(G'Z/G)__](A<!T/$R+($&+1"0,)0`$(``]
M``0``'2@BSV:?2``Z.7(__],B>:Y`@```#'22(G'Z+/'__](B<;K@V8/'T0`
M`(L%PHT@`(U0_SG:#X0G`0``BSUA?2``Z*S(__^Y!````+H!````OO):0`!(
MB<?H-<C__TB%P$B)PW0S2(M`$(L],WT@`$B+*.A[R/__NO1:0`!(B<=(B>[H
M*\?__TB+0Q!(BQCV0PY`#X4*`0``BST$?2``Z$_(__^Y!````+H!````OOE9
M0`!(B<?HV,?__TB%P$B)Q70]2(UT)`PQP+][64``Z-_C__](A<!(B<,/A(,!
M``!(BT40BSVY?"``3(L@Z`'(__](B=I(B<=,B>;HL\;__XL]G7P@`.CHQ___
M2(UT)`S&@)D`````OW)90``QP.B0X___2(7`2(G#2(D%RXP@``^$I0```+[`
M`0``2(G'Z'#%__^#^!%T#(U0`8/Z`0^'C`$``$B#Q!A;74%<05W##Q]``(/X
M`0^.T/[__[L!````9I"+/2I\(`"#PP'H<L?__TR)[DB)Q^A'Q?__.1UAC"``
M?]_IH_[__V8N#Q^$``````"+/?I[(`#H1<?__TB)WDB)Q^B:Q___Z=O^__\/
M'T0``(!X`0`/A(C]__]F#Q]$``#I=OW__P\?`$B+/0F,(`#HK/'__TB%P$B)
M!0J,(``/A-\```!(BT403(LEZ8L@`$B+&(M##"4`!"``/0`$```/A9D```!(
MBWL03(GFZ`_(__]!B<1(BT402(L8BU,,@>(`!"``@?H`!```=5!(BU,02(L%
MH8L@`$2)X;_H6T``2(LP,<#HM\;__P\?@`````!(BP6!BR``BSTS>R``3(L@
M2(M%$$B+&.ATQO__3(GF2(G?Z*GH___I<?[__XL]#GL@`.A9QO__,=*Y`@``
M`$B)WDB)Q^@GQ?__2(G"ZY*+/>QZ(`#H-\;__[D"````2(G',=)(B=[H!<7_
M_TB)Q^E&____O\!;0`#H,\;__XG!2(L%`HL@`$B)VK\07$``2(LP,<#H&,;_
M_P\?A```````54B)_5-(@^P(Z#+L__\/M@A(B<.$R70:2(U0`0\?0`"`^2\/
MM@I(#T3:2(/"`83)=>XQP.BG[O__A<!T'4B%[708@'T``'02OK!:0`!(B=_H
M2\?__T@YV'0'2(/$"%M=PTB#Q`A(B>];7>EQY/__D$B#[`B+/29Z(`#H<<7_
M_[[_____2(G'Z(3$__^+/0YZ(`#H6<7__S'2OO`]0`!(B<=(@\0(Z>;&__]F
M#Q]$``!(C071>2``2(7`=`Q(BPW%>2``Z5C$__\QR>OW#Q]``$%708G_059)
MB?9!54F)U4%43(TE2'4@`%5(C2U(=2``4TPIY3';2,']`TB#[`CH/<+__TB%
M[70>#Q^$``````!,B>I,B?9$B?]!_Q3<2(/#`4@YZW7J2(/$"%M=05Q!74%>
M05_#9F8N#Q^$``````#SPP``2(/L"$B#Q`C#`````0`"`"5S+R5S`"]P<F]C
M+W-E;&8O97AE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!005)?5$5-
M4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`
M4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'
M3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"
M4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M
M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T
M96UP+25U+25U)7,`05)'5@`8`'!E<FP`+64`+2T``%]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@```````````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@97AE
M8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*
M(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T
M(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@
M("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R
M;61I<B`D<&%R7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C
M875S92!T:&ES(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C
M('1H870@87)E('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN
M9R!W96YT('=R;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R
M>2X@(%1H:7,*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F
M;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C
M(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5
M;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA
M;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@
M<')O8V5S<RX*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O
M=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@
M=&%K92!C87)E(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]
M/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G
M+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@
M("`@("`@('!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@
M("!S;&5E<"`Q"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA
M;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP
M.PH@("`@("`@('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@
M("`@("`@("`@("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'
M24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E
M;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM0
M05)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=6
M7R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%
M3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@
M>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@
M("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D
M<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*
M("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG
M(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[
M7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G
M970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\
M)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@
M;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B([
M"@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@
M("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I
M;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@
M=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U
M=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@
M("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@
M("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R
M8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F
M.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@
M(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T
M;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.
M5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H
M(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O
M=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@
M("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@
M(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA
M;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(
M+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@
M*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@
M("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@
M("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@
M9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@
M("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@
M("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D
M96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@
M("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.
M5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@
M("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K
M*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@
M?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I
M(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@
M("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U
M9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D
M(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U
M<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#
M*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@
M(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E
M<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R
M97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@
M(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W
M:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@
M;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O
M<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S
M+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q
M=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E
M8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S
M<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG
M="!S=V%L;&]W(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@
M=VET:&]U="`M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@
M)61I<W1?8VUD(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@
M("`@:2`@(&EN<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*
M("`@("`@("!S("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@
M("`@*3L*"B`@("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M
M92`M+7!A<BUO<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*
M("`@(",@=7-E('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@
M:6YS=&5A9"!O9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF
M("AB=70@<W1I;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT
M(&%N9"!`24Y#*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@
M(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I
M;F,["B`@("`@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@
M("`@("`@("`@("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P
M=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U
M<V4@)#(B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G02<I('L*("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G
M*2!["B`@("`@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@
M("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE
M(#T@)V%L;"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q
M(&5Q("=Q)RD@>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@
M("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z
M($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H
M95]N86UE(#T@)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T
M*$!!4D=6*3L*"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PH@("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0
M)WT["B`@("`@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@
M("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@
M("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@
M("`@("`@("!E>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M
M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M
M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@
M(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S
M:&EF="A`05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D
M<&%R*2!["B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@
M(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R
M.B`D(2(["B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@
M("`@("`@("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@
M?3L*"B`@("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@
M(&QO8V%L("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@
M("`@("`@8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@
M('T*"B`@("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@
M("`@8FEN;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@
M("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PH@("`@("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@
M("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E
M<BP@)#`I"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M96YV*2!["B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M("`@("`@("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M("`@("`@("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N
M(")?7R(["B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@
M("`@("`@("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^
M<')I;G0H)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@
M("`C(%=R:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE
M*2!["B`@("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I
M.PH*("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN
M8R`]('-O<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H
M)&$I"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@
M("`@("`@?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@H@("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL
M92!E>&ES=',@=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@
M(",@1G5N;GDL(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O
M;7!R97-S+U)A=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@
M:7,@82!B86YD+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE
M(&ES<W5E+@H@("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@
M=&AE('!A:6X@;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@
M("`@("`@(",@22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL
M97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD
M,7TK*R!F;W(@:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V
M86QU97,@)4E.0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@
M(&9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@
M*"1N86UE+"`D9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I
M;&4@/2`D7SL*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H
M+BI;7D-C72DI7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO
M;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF
M("@M9B`B)&1I<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"B`@("`@("`@("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B
M+`H@("`@("`@("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN
M+BD*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@
M("`@("`@("`@("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@
M("`@("`@("!B:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/2`\1DE,13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@
M("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D
M;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@
M("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@
M?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@
M;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H
M,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@
M("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS
M."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D
M8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@
M("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D
M9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@
M("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL
M("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP
M;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*
M("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G
M;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*
M("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!0
M05(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U
M:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@
M("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@
M("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@
M("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@
M("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@
M("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@
M("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@
M("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@
M("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@
M("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@
M("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@
M:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R
M97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*
M(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[
M>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A
M<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@
M;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@
M("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*
M("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@
M<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I
M<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E
M($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U
M:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@
M1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I
M<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@
M24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E
M($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@
M("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E
M<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#
M=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE
M.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E
M<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N
M8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S
M('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R
M971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@
M("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@
M("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E
M<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*
M("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PH@("`@("`@(&UK9&ER("1S
M=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@
M("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@
M("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@
M("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@
M("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I
M9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U
M;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@
M("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T
M(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%
M3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D
M:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C
M*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA
M;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL
M96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@
M?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE
M*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@
M<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@
M:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?
M<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@
M("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@
M("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@
M>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#
M;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@
M("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M
M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C
M(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@
M("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6
M>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*
M("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D
M96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`]
M(")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@
M*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,
M14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@
M("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*
M("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*
M?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB
M97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4
M:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E
M(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L
M.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H
M(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE
M.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*7U]%3D1?7PH`````
M``````````````#`0P$;`SOT````'0````AC__]``0``:&?__^@%``!T:?__
M$`$``&AJ__]H`0``6('__[@!```8@O__&`(``'B"__\X`@``B(3__X@"``#8
MA?__V`(``$B'__\(`P``V(?__R@#``"HB/__8`,``-B(__]X`P``*(G__Y`#
M``#HB?__N`,``/B)___0`P``N(O__Q`$``#HB___*`0``*B,__]8!```B([_
M_W@$``#HCO__F`0``!B/__^X!```.)#__P@%``"XF___6`4``*B?__^8!0``
M&*#__]`%``!8H/__$`8``'B@__\H!@``Z*#__W`&````````%``````````!
M>E(``7@0`1L,!PB0`0<0%````!P```!<:/__*@``````````````%```````
M```!>E(``7@0`1L,!PB0`0``)````!P```#`8?__8`0````.$$8.&$H/"W<(
M@``_&CLJ,R0B`````$P```!$````^&C__^D6````0@X0CP)(#AB.`T(.((T$
M0@XHC`5!#C"&!D$..(,'1P[(!`/'%@XX00XP00XH0@X@0@X80@X00@X(````
M````7````)0```"8?___M@````!"#A"/`D(.&(X#0@X@C01%#BB,!4$.,(8&
M00XX@P=$#D`"<0H..$,.,$$.*$(.($(.&$(.$$(."$(+6PXX00XP00XH0@X@
M0@X80@X00@X('````/0```#X?___6`````!!#A"#`D<.(`).#A!!#@A,````
M%`$``#B`__\-`@```$(.$(\"1`X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!T<.
M4`,``0H..$$.,$$.*$(.($(.&$(.$$(."$@+`````$P```!D`0``^('__T(!
M````0@X0C0)"#AB,`T$.((8$1`XH@P5'#L`!40H.*$$.($$.&$(.$$(."$D+
M`M<*#BA!#B!!#AA"#A!"#@A#"P``+````+0!``#X@O__9@$```!!#A"&`D$.
M&(,#1`X@`UT!#AA!#A!!#@@`````````'````.0!```XA/__@0````!!#A"#
M`FD*#@A&"P)0#@@T````!`(``*B$___(`````$(.$(P"20X8A@-)#B"#!$<.
ML"`">0H.($$.&$$.$$(."$@+`````!0````\`@``0(7__RH`````1`X080X(
M`!0```!4`@``6(7__T0`````1`X0>PX(`"0```!L`@``D(7__[D`````00X0
M@P)'#K!``IX*#A!!#@A)"P`````4````E`(``"B&__\%```````````````\
M````K`(``""&__^S`0```$(.$(T"0@X8C`-)#B"&!$$.*(,%2@[@(`)B"@XH
M00X@00X80@X00@X(00L`````%````.P"``"@A___)```````````````+```
M``0#``"XA___OP````!$#A"#`@),"@X(2`L"40H."$<+0PH."$$+00X(````
M'````#0#``!(B/__VP$```!$#E`#?`$*#@A("P`````<````5`,```B*__]4
M`````%0.('$*#@A+"P```````!P```!T`P``2(K__R0`````1`X06`H."$0+
M````````3````)0#``!8BO__'P$```!"#A"/`D(.&(X#10X@C01(#BB,!4$.
M,(8&1@XX@P=$#J`!`IX*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P````!,````
MY`,``"B+__]^"P```$(.$(\"0@X8C@-"#B"-!$(.*(P%20XPA@9!#CB#!T<.
MT(,"`\$""@XX00XP00XH0@X@0@X80@X00@X(1`L``#P````T!```6);__^@#
M````0@X0C0)"#AB,`T$.((8$00XH@P5$#D`#.P(*#BA!#B!!#AA"#A!"#@A%
M"P`````T````=`0```B:__]O`````$$.$(8"1`X8@P-$#B`"50H.&$$.$$$.
M"$$+1`X81`X000X(`````!0```"L!```0)K__SH`````1`X0<0X(`"0```#$
M!```>&'__PP"````00X0@P)$#D`#E`$*#A!##@A!"P`````4````[`0``$":
M__\<``````````````!$````!`4``$B:__]E`````$(.$(\"10X8C@-%#B"-
M!$4.*(P%2`XPA@9(#CB#!TT.0&P..$$.,$$.*$(.($(.&$(.$$(."``4````
M3`4``'":__\"````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````%`B0```````,")`````````````
M``````$``````````0`````````!``````````T"`````````0````````!<
M`@````````P``````````!M````````-``````````190```````&0``````
M``#PS6```````!L`````````"``````````:`````````/C-8```````'```
M```````(`````````/7^_V\`````F`)````````%`````````)`-0```````
M!@````````"@`T````````H`````````*`4````````+`````````!@`````
M````%0````````````````````,``````````-!@```````"`````````'@&
M````````%``````````'`````````!<`````````B!1````````'````````
M`!`40```````"`````````!X``````````D`````````&`````````#^__]O
M`````)`30```````____;P`````"`````````/#__V\`````N!)`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````C.8````````````````````````````#8;0```````
M1AM```````!6&T```````&8;0```````=AM```````"&&T```````)8;0```
M````IAM```````"V&T```````,8;0```````UAM```````#F&T```````/8;
M0```````!AQ````````6'$```````"8<0```````-AQ```````!&'$``````
M`%8<0```````9AQ```````!V'$```````(8<0```````EAQ```````"F'$``
M`````+8<0```````QAQ```````#6'$```````.8<0```````]AQ````````&
M'4```````!8=0```````)AU````````V'4```````$8=0```````5AU`````
M``!F'4```````'8=0```````AAU```````"6'4```````*8=0```````MAU`
M``````#&'4```````-8=0```````YAU```````#V'4````````8>0```````
M%AY````````F'D```````#8>0```````1AY```````!6'D```````&8>0```
M````=AY```````"&'D```````)8>0```````IAY```````"V'D```````,8>
M0```````UAY```````#F'D```````/8>0```````!A]````````6'T``````
M`"8?0```````-A]```````!&'T```````%8?0```````9A]```````!V'T``
M``````````````````````````#_____`````%A<0```````1T-#.B`H56)U
M;G1U(#0N."XR+3(S=6)U;G1U,2D@-"XX+C(`1T-#.B`H56)U;G1U(#0N."XR
M+3$Y=6)U;G1U,2D@-"XX+C(``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"
M22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?
M:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD
M>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````#@"0```````.`(`````
M```<`````````````````````0```````````````````!,````'`````@``
M``````!4`D```````%0"````````(`````````````````````0`````````
M```````````A````!P````(`````````=`)```````!T`@```````"0`````
M```````````````$````````````````````-````/;__V\"`````````)@"
M0```````F`(````````$`0````````4`````````"```````````````````
M`#X````+`````@````````"@`T```````*`#````````\`D````````&````
M`0````@`````````&`````````!&`````P````(`````````D`U```````"0
M#0```````"@%```````````````````!````````````````````3@```/__
M_V\"`````````+@20```````N!(```````#4``````````4``````````@``
M```````"`````````%L```#^__]O`@````````"0$T```````)`3````````
M@``````````&`````@````@```````````````````!J````!`````(`````
M````$!1````````0%````````'@`````````!0`````````(`````````!@`
M````````=`````0```!"`````````(@40```````B!0```````!X!@``````
M``4````,````"``````````8`````````'X````!````!@``````````&T``
M```````;````````&@````````````````````0```````````````````!Y
M`````0````8`````````(!M````````@&P```````&`$````````````````
M```0`````````!``````````A`````$````&`````````(`?0```````@!\`
M``````"".0``````````````````$````````````````````(H````!````
M!@`````````$64````````19````````"0````````````````````0`````
M``````````````"0`````0````(`````````$%E````````060````````A?
M```````````````````(````````````````````F`````$````"````````
M`!BX0```````&+@```````#T````````````````````!```````````````
M`````*8````!`````@`````````0N4```````!"Y````````E`4`````````
M``````````@```````````````````"P````#@````,`````````\,U@````
M``#PS0````````@````````````````````(````````````````````O```
M``\````#`````````/C-8```````^,T````````(````````````````````
M"````````````````````,@````!`````P``````````SF````````#.````
M````"`````````````````````@```````````````````#-````!@````,`
M````````",Y@```````(S@```````/`!````````!@`````````(````````
M`!``````````U@````$````#`````````/C/8```````^,\````````(````
M````````````````"``````````(`````````-L````!`````P``````````
MT&````````#0````````0`(```````````````````@`````````"```````
M``#D`````0````,`````````0-)@``````!`T@```````"``````````````
M```````(````````````````````Z@````@````#`````````&#28```````
M8-(```````!H$```````````````````(````````````````````.\````!
M````,````````````````````&#2````````2`````````````````````$`
M`````````0`````````!`````P````````````````````````"HT@``````
A`/@````````````````````!````````````````````
